==> OpenPatricianEngine-0.8.0-sources.jar: ch/sahits/game/openpatrician/engine/event/task/LoanerCollectMoneyAfterAuctionTimedTask.java <==
package ch.sahits.game.openpatrician.engine.event.task;

import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.Prototype;
import ch.sahits.game.openpatrician.model.DisplayMessage;
import ch.sahits.game.openpatrician.model.ICompany;
import ch.sahits.game.openpatrician.model.IHumanPlayer;
import ch.sahits.game.openpatrician.model.IPlayer;
import ch.sahits.game.openpatrician.model.city.impl.IDebt;
import ch.sahits.game.openpatrician.model.event.TargetedEvent;
import ch.sahits.game.openpatrician.model.event.TimedTask;
import com.google.common.eventbus.AsyncEventBus;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

/**
 * Timed task for the loaner to collect money after an auction.
 * Created by andi on 26.03.17.
 */
@Prototype
@ClassCategory({EClassCategory.SERIALIZABLE_BEAN, EClassCategory.PROTOTYPE_BEAN})
public class LoanerCollectMoneyAfterAuctionTimedTask extends TimedTask {
    @Autowired
    @Qualifier("serverClientEventBus")
    @XStreamOmitField
    private AsyncEventBus clientServerEventBus;

    private IDebt debt;

    public LoanerCollectMoneyAfterAuctionTimedTask(IDebt debt, DateTime deadline) {
        this.debt = debt;
        setExecutionTime(deadline);
    }

    @Override
    public void run() {
        IHumanPlayer debitor = (IHumanPlayer) debt.getDebitor();
        ICompany company = debitor.getCompany();
        int requiredAmount = debt.getAmount();
        int amount = (int) Math.min(requiredAmount, company.getCash());
        company.updateCash(-amount);
        if (debt.getCreditor() instanceof IPlayer) {
            ((IPlayer)debt.getCreditor()).getCompany().updateCash(amount);
            if (debt.getCreditor() instanceof IHumanPlayer) {
                DisplayMessage msg = new DisplayMessage("ch.sahits.game.openpatrician.engine.land.city.LoanerEngine.paybackAfterShipAuction", new Object[]{debitor.getName(), debitor.getLastName(), amount});
                TargetedEvent message = new TargetedEvent((IHumanPlayer) debt.getCreditor(), msg);
                clientServerEventBus.post(message);
            }
        }
    }
}

==> OpenPatricianEngine-0.9.1-sources.jar: ch/sahits/game/openpatrician/engine/event/task/LoanerCollectMoneyAfterAuctionTimedTask.java <==
package ch.sahits.game.openpatrician.engine.event.task;

import ch.sahits.game.openpatrician.model.DisplayMessage;
import ch.sahits.game.openpatrician.model.ICompany;
import ch.sahits.game.openpatrician.model.IHumanPlayer;
import ch.sahits.game.openpatrician.model.IPlayer;
import ch.sahits.game.openpatrician.model.city.impl.IDebt;
import ch.sahits.game.openpatrician.model.event.TargetedEvent;
import ch.sahits.game.openpatrician.model.event.TimedTask;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.Prototype;
import com.google.common.eventbus.AsyncEventBus;
import com.thoughtworks.xstream.annotations.XStreamOmitField;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

import java.time.LocalDateTime;

/**
 * Timed task for the loaner to collect money after an auction.
 * Created by andi on 26.03.17.
 */
@Prototype
@ClassCategory({EClassCategory.SERIALIZABLE_BEAN, EClassCategory.PROTOTYPE_BEAN})
public class LoanerCollectMoneyAfterAuctionTimedTask extends TimedTask {
    @Autowired
    @Qualifier("serverClientEventBus")
    @XStreamOmitField
    private AsyncEventBus clientServerEventBus;

    private IDebt debt;

    public LoanerCollectMoneyAfterAuctionTimedTask(IDebt debt, LocalDateTime deadline) {
        this.debt = debt;
        setExecutionTime(deadline);
    }

    @Override
    public void run() {
        IHumanPlayer debitor = (IHumanPlayer) debt.getDebitor();
        ICompany company = debitor.getCompany();
        int requiredAmount = debt.getAmount();
        int amount = (int) Math.min(requiredAmount, company.getCash());
        company.updateCash(-amount);
        if (debt.getCreditor() instanceof IPlayer) {
            if (debt.getCreditor() instanceof IHumanPlayer) {
                ((IPlayer) debt.getCreditor()).getCompany().updateCash(amount);
            } else {
                ((IPlayer) debt.getCreditor()).getCompany().updateCashDirectly(amount);
            }
            if (debt.getCreditor() instanceof IHumanPlayer) {
                DisplayMessage msg = new DisplayMessage("ch.sahits.game.openpatrician.engine.land.city.LoanerEngine.paybackAfterShipAuction", new Object[]{debitor.getName(), debitor.getLastName(), amount});
                TargetedEvent message = new TargetedEvent((IHumanPlayer) debt.getCreditor(), msg);
                clientServerEventBus.post(message);
            }
        }
    }
}
